Index: src/arm/lithium-codegen-arm.cc |
diff --git a/src/arm/lithium-codegen-arm.cc b/src/arm/lithium-codegen-arm.cc |
index 36aec4544625783653567becf52f1483eb42d1d5..d0f8a865cc5200d4e3550806c28a7226a935ac26 100644 |
--- a/src/arm/lithium-codegen-arm.cc |
+++ b/src/arm/lithium-codegen-arm.cc |
@@ -188,7 +188,7 @@ bool LCodeGen::GeneratePrologue() { |
need_write_barrier = false; |
} else { |
__ push(r1); |
- __ CallRuntime(Runtime::kHiddenNewFunctionContext, 1); |
+ __ CallRuntime(Runtime::kNewFunctionContext, 1); |
} |
RecordSafepoint(Safepoint::kNoLazyDeopt); |
// Context is returned in both r0 and cp. It replaces the context |
@@ -3575,7 +3575,7 @@ void LCodeGen::DoDeclareGlobals(LDeclareGlobals* instr) { |
__ push(scratch0()); |
__ mov(scratch0(), Operand(Smi::FromInt(instr->hydrogen()->flags()))); |
__ push(scratch0()); |
- CallRuntime(Runtime::kHiddenDeclareGlobals, 3, instr); |
+ CallRuntime(Runtime::kDeclareGlobals, 3, instr); |
} |
@@ -3666,7 +3666,7 @@ void LCodeGen::DoDeferredMathAbsTaggedHeapNumber(LMathAbs* instr) { |
// Slow case: Call the runtime system to do the number allocation. |
__ bind(&slow); |
- CallRuntimeFromDeferred(Runtime::kHiddenAllocateHeapNumber, 0, instr, |
+ CallRuntimeFromDeferred(Runtime::kAllocateHeapNumber, 0, instr, |
instr->context()); |
// Set the pointer to the new heap number in tmp. |
if (!tmp1.is(r0)) __ mov(tmp1, Operand(r0)); |
@@ -4478,7 +4478,7 @@ void LCodeGen::DoDeferredStringCharCodeAt(LStringCharCodeAt* instr) { |
__ SmiTag(index); |
__ push(index); |
} |
- CallRuntimeFromDeferred(Runtime::kHiddenStringCharCodeAt, 2, instr, |
+ CallRuntimeFromDeferred(Runtime::kStringCharCodeAtRT, 2, instr, |
instr->context()); |
__ AssertSmi(r0); |
__ SmiUntag(r0); |
@@ -4665,11 +4665,11 @@ void LCodeGen::DoDeferredNumberTagIU(LInstruction* instr, |
// NumberTagI and NumberTagD use the context from the frame, rather than |
// the environment's HContext or HInlinedContext value. |
// They only call Runtime::kHiddenAllocateHeapNumber. |
// The corresponding HChange instructions are added in a phase that does |
// not have easy access to the local context. |
__ ldr(cp, MemOperand(fp, StandardFrameConstants::kContextOffset)); |
- __ CallRuntimeSaveDoubles(Runtime::kHiddenAllocateHeapNumber); |
+ __ CallRuntimeSaveDoubles(Runtime::kAllocateHeapNumber); |
RecordSafepointWithRegisters( |
instr->pointer_map(), 0, Safepoint::kNoLazyDeopt); |
__ sub(r0, r0, Operand(kHeapObjectTag)); |
@@ -4729,11 +4729,11 @@ void LCodeGen::DoDeferredNumberTagD(LNumberTagD* instr) { |
PushSafepointRegistersScope scope(this, Safepoint::kWithRegisters); |
// NumberTagI and NumberTagD use the context from the frame, rather than |
// the environment's HContext or HInlinedContext value. |
// They only call Runtime::kHiddenAllocateHeapNumber. |
// The corresponding HChange instructions are added in a phase that does |
// not have easy access to the local context. |
__ ldr(cp, MemOperand(fp, StandardFrameConstants::kContextOffset)); |
- __ CallRuntimeSaveDoubles(Runtime::kHiddenAllocateHeapNumber); |
+ __ CallRuntimeSaveDoubles(Runtime::kAllocateHeapNumber); |
RecordSafepointWithRegisters( |
instr->pointer_map(), 0, Safepoint::kNoLazyDeopt); |
__ sub(r0, r0, Operand(kHeapObjectTag)); |
@@ -5347,7 +5347,7 @@ void LCodeGen::DoDeferredAllocate(LAllocate* instr) { |
__ Push(Smi::FromInt(flags)); |
CallRuntimeFromDeferred( |
- Runtime::kHiddenAllocateInTargetSpace, 2, instr, instr->context()); |
+ Runtime::kAllocateInTargetSpace, 2, instr, instr->context()); |
__ StoreToSafepointRegisterSlot(r0, result); |
} |
@@ -5381,7 +5381,7 @@ void LCodeGen::DoRegExpLiteral(LRegExpLiteral* instr) { |
__ mov(r4, Operand(instr->hydrogen()->pattern())); |
__ mov(r3, Operand(instr->hydrogen()->flags())); |
__ Push(r6, r5, r4, r3); |
- CallRuntime(Runtime::kHiddenMaterializeRegExpLiteral, 4, instr); |
+ CallRuntime(Runtime::kMaterializeRegExpLiteral, 4, instr); |
__ mov(r1, r0); |
__ bind(&materialized); |
@@ -5394,7 +5394,7 @@ void LCodeGen::DoRegExpLiteral(LRegExpLiteral* instr) { |
__ bind(&runtime_allocate); |
__ mov(r0, Operand(Smi::FromInt(size))); |
__ Push(r1, r0); |
- CallRuntime(Runtime::kHiddenAllocateInNewSpace, 1, instr); |
+ CallRuntime(Runtime::kAllocateInNewSpace, 1, instr); |
__ pop(r1); |
__ bind(&allocated); |
@@ -5419,7 +5419,7 @@ void LCodeGen::DoFunctionLiteral(LFunctionLiteral* instr) { |
__ mov(r1, Operand(pretenure ? factory()->true_value() |
: factory()->false_value())); |
__ Push(cp, r2, r1); |
- CallRuntime(Runtime::kHiddenNewClosure, 3, instr); |
+ CallRuntime(Runtime::kNewClosure, 3, instr); |
} |
} |
@@ -5606,7 +5606,7 @@ void LCodeGen::DoDummyUse(LDummyUse* instr) { |
void LCodeGen::DoDeferredStackCheck(LStackCheck* instr) { |
PushSafepointRegistersScope scope(this, Safepoint::kWithRegisters); |
LoadContextFromDeferred(instr->context()); |
- __ CallRuntimeSaveDoubles(Runtime::kHiddenStackGuard); |
+ __ CallRuntimeSaveDoubles(Runtime::kStackGuard); |
RecordSafepointWithLazyDeopt( |
instr, RECORD_SAFEPOINT_WITH_REGISTERS_AND_NO_ARGUMENTS); |
ASSERT(instr->HasEnvironment()); |
@@ -5832,7 +5832,7 @@ void LCodeGen::DoAllocateBlockContext(LAllocateBlockContext* instr) { |
Handle<ScopeInfo> scope_info = instr->scope_info(); |
__ Push(scope_info); |
__ push(ToRegister(instr->function())); |
- CallRuntime(Runtime::kHiddenPushBlockContext, 2, instr); |
+ CallRuntime(Runtime::kPushBlockContext, 2, instr); |
RecordSafepoint(Safepoint::kNoLazyDeopt); |
} |
@@ -4665,11 +4665,11 @@ void LCodeGen::DoDeferredNumberTagIU(LInstruction* instr, |
// NumberTagI and NumberTagD use the context from the frame, rather than |
// the environment's HContext or HInlinedContext value. |
- // They only call Runtime::kHiddenAllocateHeapNumber. |
+ // They only call Runtime::kAllocateHeapNumber. |
// The corresponding HChange instructions are added in a phase that does |
// not have easy access to the local context. |
@@ -4729,11 +4729,11 @@ void LCodeGen::DoDeferredNumberTagD(LNumberTagD* instr) { |
// NumberTagI and NumberTagD use the context from the frame, rather than |
// the environment's HContext or HInlinedContext value. |
- // They only call Runtime::kHiddenAllocateHeapNumber. |
+ // They only call Runtime::kAllocateHeapNumber. |
// The corresponding HChange instructions are added in a phase that does |
// not have easy access to the local context. |